@@ -17,7 +17,9 @@ from isisdl.backend.utils import User, path, sanitize_name, args, on_kill, datab
 from isisdl.settings import enable_multithread, checksum_algorithm, video_size_discover_num_threads
 
 ignored_urls = {
-    'https://isis.tu-berlin.de/mod/resource/view.php?id=756880'
+    "https://isis.tu-berlin.de/mod/resource/view.php?id=756880",
+    "https://isis.tu-berlin.de/mod/resource/view.php?id=910864",
+
 }
 
 
@@ -100,7 +102,7 @@ class Course:
             os.makedirs(self.path(item), exist_ok=True)
 
     def download_videos(self, s: SessionWithKey) -> List[PreMediaContainer]:
-        if args.disable_videos or not config.download_videos:
+        if config.download_videos:
             return []
 
         url = "https://isis.tu-berlin.de/lib/ajax/service.php"
@@ -151,9 +153,6 @@ class Course:
                 for item in videos_json]
 
     def download_documents(self, helper: RequestHelper) -> List[PreMediaContainer]:
-        if args.disable_documents:
-            return []
-
         content = helper.post_REST("core_course_get_contents", {"courseid": self.course_id})
         if content is None:
             return []
@@ -173,6 +172,7 @@ class Course:
                     continue
 
                 # This is a definite blacklist on stuff we don't want to follow.
+                # TODO: mod/book
                 ignore = re.match(
                     ".*mod/(?:"
                     "forum|url|choicegroup|assign|videoservice|feedback|choice|quiz|glossary|questionnaire|scorm|etherpadlite|lti|h5pactivity|"
@@ -415,9 +415,6 @@ class RequestHelper:
         return all_files
 
     def download_mod_assign(self) -> List[PreMediaContainer]:
-        if args.disable_documents:
-            return []
-
         all_content = []
         _assignments = self.post_REST('mod_assign_get_assignments')
         if _assignments is None:
